@@ -8,7 +8,7 @@ impl<T, E> ScanFn for CollectState<T, E> {
     type InputItem = T;
     type InputResult = E;
     type OutputItem = ();
-    type OutputResult = Vec<T>;
+    type OutputResult = (Vec<T>, Self::InputResult);
 
     fn map_input(mut self, input: Self::InputItem) -> ScanState<Self> {
         self.0.push(input);
@@ -18,8 +18,8 @@ impl<T, E> ScanFn for CollectState<T, E> {
         }
     }
 
-    fn map_result(self, _: Self::InputResult) -> Self::OutputResult {
-        self.0
+    fn map_result(self, result: Self::InputResult) -> Self::OutputResult {
+        (self.0, result)
     }
 }
 
@@ -28,7 +28,7 @@ where
     Self: ListFn,
     Self::End: ResultFn,
 {
-    fn collect(self) -> Vec<Self::Item> {
+    fn collect(self) -> (Vec<Self::Item>, <Self::End as ResultFn>::Result) {
         self.scan(CollectState(Vec::new(), PhantomData::default()))
             .fold()
     }
